// set function parseTime,formatTime to filter
export { parseTime, numFilter, formatTime }
from '../utils'
// import Vue from 'vue'

function pluralize(time, label) {
    if (time < 1) {
        return '刚刚'
    }
    return time + label
}

function padding(s, len) {
    var len = len - (s + '').length
    for (var i = 0; i < len; i++) { s = '0' + s }
    return s
}

export function timeAgo(date) {
    if (typeof (date) === "undefined" || date == null || date == '') {
        return "----";
    }

    const time = new Date(date).getTime();
    const between = (Date.now() - Number(time)) / 1000;
    if (between < 3600) {
        return pluralize(~~(between / 60), ' 分钟前')
    } else if (between < 86400) {
        return pluralize(~~(between / 3600), ' 小时前')
    } else {
        return pluralize(~~(between / 86400), ' 天前')
    }
}

/* 数字 格式化*/
export function numberFormatter(num, digits) {
    const si = [
        { value: 1E18, symbol: 'E' },
        { value: 1E15, symbol: 'P' },
        { value: 1E12, symbol: 'T' },
        { value: 1E9, symbol: 'G' },
        { value: 1E6, symbol: 'M' },
        { value: 1E3, symbol: 'k' }
    ]
    for (let i = 0; i < si.length; i++) {
        if (num >= si[i].value) {
            return (num / si[i].value + 0.1).toFixed(digits).replace(/\.0+$|(\.[0-9]*[1-9])0+$/, '$1') + si[i].symbol
        }
    }
    return num.toString()
}

export function toThousandslsFilter(num) {
    return (+num || 0).toString().replace(/^-?\d+/g, m => m.replace(/(?=(?!\b)(\d{3})+$)/g, ','))
}

// 定义一个图片过滤器
export function DFSImg(path, w, h) {
    if (path == null || path === '') {
        return 'https://mayi-newshop.oss-cn-shanghai.aliyuncs.com/product/5RrnPAzh24.gif'
    }
    if (path.indexOf('http') === 0) {
        return path
    }

    const baseImg = process.env.IMG_DOMAIN
        //   let num = Math.floor(Math.random()*baseImg.length)
        //   var uri = baseImg[num]
    if (path.indexOf('/') !== 0) {
        path = '/' + path
    }
    var ext = path.substring(path.lastIndexOf(".")+1).toLocaleLowerCase()
    if(ext == 'gif'){
        return baseImg + path
    }
    if (!Array.isArray(baseImg) && (baseImg.indexOf('aliyun') >= 0 || baseImg.indexOf('cdn') >= 0 )) {
        var style = ''
        if (w) style += ',w_' + w
        if (h) style += ',h_' + h
        if (style.length > 0) {
            path += '?x-oss-process=image/resize,m_pad,limit_0' + style
        }
        return baseImg + path
    } else {
        if (w && h) {
            path += '.' + w + 'x' + h + '.jpg'
        }
        return baseImg[Math.floor(Math.random() * 100) % baseImg.length] + path
    }
}

/**
 * 权益图标
 *
 * @export
 * @param {*} path
 * @param {*} w
 * @param {*} h
 * @returns
 */
// export function DFSRightImg(path, systemCode, w, h) {
//   if (path == null || path == "") {
//     if (systemCode == "FREE_SHIPPING") {
//       return require("../assets/img/right/FREE_SHIPPING.png");
//     } else if (systemCode == "DISCOUNT") {
//       return require("../assets/img/right/DISCOUNT.png");
//     } else if (systemCode == "DISTRIBUTION") {
//       return require("../assets/img/right/DISTRIBUTION.png");
//     } else if(systemCode == "OPEN_VIP_LOGO") {
//       return require("../assets/img/right/OPEN_VIP_LOGO.png");
//     } else {
//       return '';
//     }
//   }

//   return DFSImg(path, w, h);
// }

// 转换sys_code
// export function sysCodeFileter(code, type) {
//     if (code === null) {
//         return ''
//     }

//     const typeArr = Vue.prototype.SYS_CODE[type]
//     if (!typeArr) {
//         return ''
//     }

//     for (var i in typeArr) {
//         const element = typeArr[i]
//         if (element.key === code + '') {
//             return element.display_name
//         }
//     }

//     return ''
// }

// export function sysCodeListFileter(code, type) {
//     if (code === null) {
//         return ''
//     }

//     const typeArr = Vue.prototype.SYS_CODE[type]
//     if (!typeArr) {
//         return type + '未定义'
//     }
//     let codes = code.split(',')
//     let list = []
//     for (let i = 0; i < typeArr.length; i++) {
//         for (let j = 0; j < codes.length; j++) {
//             if (typeArr[i].key == codes[j]) {
//                 list.push(typeArr[i].display_name)
//             }
//         }
//     }
//     let value = list.join(',')

//     return value
// }

export function formatDate(date, fmt) {
    if (typeof(date) === "undefined" || date == null || date == '') {
        return "----";
    }

    // 本系统返回值都是string，这段注释掉
    // if (typeof(date) === "string") {
    //     date = parseFloat(date);
    // }

    date = new Date(date);
    if (typeof(fmt) === "undefined") {
        fmt = "yyyy-MM-dd hh:mm:ss";
    }
    if (/(y+)/.test(fmt)) {
        fmt = fmt.replace(RegExp.$1, (date.getFullYear() + '').substr(4 - RegExp.$1.length))
    }
    let o = {
        'M+': date.getMonth() + 1,
        'd+': date.getDate(),
        'h+': date.getHours(),
        'm+': date.getMinutes(),
        's+': date.getSeconds(),
        'S+': date.getMilliseconds()
    }
    for (let k in o) {
        if (new RegExp(`(${k})`).test(fmt)) {
            let str = o[k] + ''
            fmt = fmt.replace(RegExp.$1, RegExp.$1.length === 1 ? str : padding(str, RegExp.$1.length));
        }
    }
    return fmt
}

export function NToStr(val) {
    if (val) {
        return parseFloat(parseFloat(val).toFixed(2))
    } else {
        return 0
    }
}

/**
 * 文字截取
 * @param {*} value
 * @param {*} byte
 */
export function stringCut(value, byte = 2) {
    if (!value || value === 'undefined') {
        return value;
    }
    let length = byte;
    return value.substr(0, length);
}

/**
 * 格式化为两位小数
 * @param {*} data
 */
export function formatTwoDecimal(data) {
    if (data) {
        return Math.round(parseFloat(data) * 100) / 100;
    } else {
        return 0.00;
    }
}
