/**
 * Created by jiachenpan on 16/11/18.
 */
// import store from '@/store'
// import XLSX from 'xlsx'
// import moment from 'moment'

export function parseTime(time, cFormat) {
  if (time == null) {
    return ''
  }
  if (arguments.length === 0) {
    return null
  }
  const format = cFormat || '{y}-{m}-{d} {h}:{i}:{s}'
  let date
  if (typeof time === 'object') {
    date = time
  } else {
    if (('' + time).length === 10) time = parseInt(time) * 1000
    date = new Date(time)
  }
  const formatObj = {
    y: date.getFullYear(),
    m: date.getMonth() + 1,
    d: date.getDate(),
    h: date.getHours(),
    i: date.getMinutes(),
    s: date.getSeconds(),
    a: date.getDay()
  }
  const time_str = format.replace(/{(y|m|d|h|i|s|a)+}/g, (result, key) => {
    let value = formatObj[key]
    if (key === 'a') { return ['一', '二', '三', '四', '五', '六', '日'][value - 1] }
    if (result.length > 0 && value < 10) {
      value = '0' + value
    }
    return value || 0
  })
  return time_str
}

export function formatTime(time, option) {
  time = +time * 1000
  const d = new Date(time)
  const now = Date.now()

  const diff = (now - d) / 1000

  if (diff < 30) {
    return '刚刚'
  } else if (diff < 3600) {
    // less 1 hour
    return Math.ceil(diff / 60) + '分钟前'
  } else if (diff < 3600 * 24) {
    return Math.ceil(diff / 3600) + '小时前'
  } else if (diff < 3600 * 24 * 2) {
    return '1天前'
  }
  if (option) {
    return parseTime(time, option)
  } else {
    return (
      d.getMonth() +
      1 +
      '月' +
      d.getDate() +
      '日' +
      d.getHours() +
      '时' +
      d.getMinutes() +
      '分'
    )
  }
}

// 格式化时间
export function getQueryObject(url) {
  url = url == null ? window.location.href : url
  const search = url.substring(url.lastIndexOf('?') + 1)
  const obj = {}
  const reg = /([^?&=]+)=([^?&=]*)/g
  search.replace(reg, (rs, $1, $2) => {
    const name = decodeURIComponent($1)
    let val = decodeURIComponent($2)
    val = String(val)
    obj[name] = val
    return rs
  })
  return obj
}

/**
 *get getByteLen
 * @param {Sting} val input value
 * @returns {number} output value
 */
export function getByteLen(val) {
  let len = 0
  for (let i = 0; i < val.length; i++) {
    if (val[i].match(/[^\x00-\xff]/gi) != null) {
      len += 1
    } else {
      len += 0.5
    }
  }
  return Math.floor(len)
}

export function cleanArray(actual) {
  const newArray = []
  for (let i = 0; i < actual.length; i++) {
    if (actual[i]) {
      newArray.push(actual[i])
    }
  }
  return newArray
}

export function param(json) {
  if (!json) return ''
  return cleanArray(
    Object.keys(json).map(key => {
      if (json[key] === undefined) return ''
      return encodeURIComponent(key) + '=' + encodeURIComponent(json[key])
    })
  ).join('&')
}

export function param2Obj(url) {
  const search = url.split('?')[1]
  if (!search) {
    return {}
  }
  return JSON.parse(
    '{"' +
      decodeURIComponent(search)
        .replace(/"/g, '\\"')
        .replace(/&/g, '","')
        .replace(/=/g, '":"') +
      '"}'
  )
}

export function html2Text(val) {
  const div = document.createElement('div')
  div.innerHTML = val
  return div.textContent || div.innerText
}

export function objectMerge(target, source) {
  /* Merges two  objects,
     giving the last one precedence */

  if (typeof target !== 'object') {
    target = {}
  }
  if (Array.isArray(source)) {
    return source.slice()
  }
  Object.keys(source).forEach(property => {
    const sourceProperty = source[property]
    if (typeof sourceProperty === 'object') {
      target[property] = objectMerge(target[property], sourceProperty)
    } else {
      target[property] = sourceProperty
    }
  })
  return target
}

export function scrollTo(element, to, duration) {
  if (duration <= 0) return
  const difference = to - element.scrollTop
  const perTick = (difference / duration) * 10
  setTimeout(() => {
    console.log(new Date())
    element.scrollTop = element.scrollTop + perTick
    if (element.scrollTop === to) return
    scrollTo(element, to, duration - 10)
  }, 10)
}

export function toggleClass(element, className) {
  if (!element || !className) {
    return
  }
  let classString = element.className
  const nameIndex = classString.indexOf(className)
  if (nameIndex === -1) {
    classString += '' + className
  } else {
    classString =
      classString.substr(0, nameIndex) +
      classString.substr(nameIndex + className.length)
  }
  element.className = classString
}

// export const datePickerShortcuts = [
//   {
//     text: '今天',
//     onClick(picker) {
//       const y = moment()
//       const start = y.set({ 'hour': 0, 'minute': 0, 'second': 0 }).toDate()
//       const end = y.set({ 'hour': 23, 'minute': 59, 'second': 59 }).toDate()
//       picker.$emit('pick', [start, end])
//     }
//   },
//   {
//     text: '昨天',
//     onClick(picker) {
//       const y = moment().subtract(1, 'days')
//       const start = y.set({ 'hour': 0, 'minute': 0, 'second': 0 }).toDate()
//       const end = y.set({ 'hour': 23, 'minute': 59, 'second': 59 }).toDate()
//       picker.$emit('pick', [start, end])
//     }
//   },
//   {
//     text: '前天',
//     onClick(picker) {
//       const y = moment().subtract(2, 'days')
//       const start = y.set({ 'hour': 0, 'minute': 0, 'second': 0 }).toDate()
//       const end = y.set({ 'hour': 23, 'minute': 59, 'second': 59 }).toDate()
//       picker.$emit('pick', [start, end])
//     }
//   },
//   {
//     text: '过去7天',
//     onClick(picker) {
//       const y = moment()
//       const end = y.set({ 'hour': 23, 'minute': 59, 'second': 59 }).toDate()
//       const start = y.subtract(7, 'days').set({ 'hour': 0, 'minute': 0, 'second': 0 }).toDate()
//       picker.$emit('pick', [start, end])
//     }
//   },
//   {
//     text: '过去30天',
//     onClick(picker) {
//       const y = moment()
//       const end = y.set({ 'hour': 23, 'minute': 59, 'second': 59 }).toDate()
//       const start = y.subtract(30, 'days').set({ 'hour': 0, 'minute': 0, 'second': 0 }).toDate()
//       picker.$emit('pick', [start, end])
//     }
//   },
//   {
//     text: '过去90天',
//     onClick(picker) {
//       const y = moment()
//       const end = y.set({ 'hour': 23, 'minute': 59, 'second': 59 }).toDate()
//       const start = y.subtract(90, 'days').set({ 'hour': 0, 'minute': 0, 'second': 0 }).toDate()
//       picker.$emit('pick', [start, end])
//     }
//   },
//   {
//     text: '本周',
//     onClick(picker) {
//       const start = moment().weekday(1).set({ 'hour': 0, 'minute': 0, 'second': 0 }).toDate()
//       const end = moment().weekday(7).set({ 'hour': 23, 'minute': 59, 'second': 59 }).toDate()
//       picker.$emit('pick', [start, end])
//     }
//   },
//   {
//     text: '本月',
//     onClick(picker) {
//       const y = moment()
//       const end = y.date(31).set({ 'hour': 23, 'minute': 59, 'second': 59 }).toDate()
//       const start = y.date(1).set({ 'hour': 0, 'minute': 0, 'second': 0 }).toDate()
//       picker.$emit('pick', [start, end])
//     }
//   }
// ]

export function getTime(type) {
  if (type === 'start') {
    return new Date().getTime() - 3600 * 1000 * 24 * 90
  } else {
    return new Date(new Date().toDateString())
  }
}

export function debounce(func, wait, immediate) {
  let timeout, args, context, timestamp, result

  const later = function() {
    // 据上一次触发时间间隔
    const last = +new Date() - timestamp

    // 上次被包装函数被调用时间间隔last小于设定时间间隔wait
    if (last < wait && last > 0) {
      timeout = setTimeout(later, wait - last)
    } else {
      timeout = null
      // 如果设定为immediate===true，因为开始边界已经调用过了此处无需调用
      if (!immediate) {
        result = func.apply(context, args)
        if (!timeout) context = args = null
      }
    }
  }

  return function(...args) {
    context = this
    timestamp = +new Date()
    const callNow = immediate && !timeout
    // 如果延时不存在，重新设定延时
    if (!timeout) timeout = setTimeout(later, wait)
    if (callNow) {
      result = func.apply(context, args)
      context = args = null
    }

    return result
  }
}

/**
 * This is just a simple version of deep copy
 * Has a lot of edge cases bug
 * If you want to use a perfect deep copy, use lodash's _.cloneDeep
 */
export function deepClone(source) {
  if (!source && typeof source !== 'object') {
    throw new Error('error arguments', 'shallowClone')
  }
  const targetObj = source.constructor === Array ? [] : {}
  Object.keys(source).forEach(keys => {
    if (source[keys] && typeof source[keys] === 'object') {
      targetObj[keys] = deepClone(source[keys])
    } else {
      targetObj[keys] = source[keys]
    }
  })
  return targetObj
}

export function uniqueArr(arr) {
  return Array.from(new Set(arr))
}
export function fixdata(data) {
  let o = ''
  let l = 0
  const w = 10240
  for (; l < data.byteLength / w; ++l) o += String.fromCharCode.apply(null, new Uint8Array(data.slice(l * w, l * w + w)))
  o += String.fromCharCode.apply(null, new Uint8Array(data.slice(l * w)))
  return o
}
// export function get_header_row(sheet) {
//   const headers = []
//   const range = XLSX.utils.decode_range(sheet['!ref'])
//   let C
//   const R = range.s.r /* start in the first row */
//   for (C = range.s.c; C <= range.e.c; ++C) { /* walk every column in the range */
//     var cell = sheet[XLSX.utils.encode_cell({ c: C, r: R })] /* find the cell in the first row */
//     var hdr = 'UNKNOWN ' + C // <-- replace with your desired default
//     if (cell && cell.t) hdr = XLSX.utils.format_cell(cell)
//     headers.push(hdr)
//   }
//   return headers
// }
// 截取当前数据到小数点后两位
export function numFilter(value) {
  if (value === '0E-9') {
    return 0.0000
  }else if(value===undefined){
    return null;
  } else {
    const realVal = Number(value).toFixed(4)
    return realVal
  }
}

/**
 * 检查登陆用户是否为平台人员
 *
 * @export
 * @param {*} value
 * @returns
 */
// export function isPlatform() {
//   return store.state.user.groupId == '0';
// }

/**
 * 检查文件类型为图片还是视频
 *
 * @export
 * @param {*} value
 * @returns
 */
export function getFileType(name) {
  if(!name) return false;
  var imgType=["gif", "jpeg", "jpg", "bmp", "png"];
  var videoType=["avi","wmv","mkv","mp4","mov","rm","3gp","flv","mpg","rmvb"];
  if(RegExp("\.(" + imgType.join("|") + ")$", "i").test(name.toLowerCase())) {
      return 'image';
  } else if(RegExp("\.(" + videoType.join("|") + ")$", "i").test(name.toLowerCase())) {
      return 'video';
  } else {
    return false;
  }
}
